==> jc-1.4.0.tar.gz: gnu/java/nio/PipeImpl__24SinkChannelImpl.h <==
// public final class gnu.java.nio.PipeImpl$SinkChannelImpl

// class file dependencies
// @dep_class 605b501836d0d19a gnu_java_nio_PipeImpl__24SinkChannelImpl
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8a9bac808797868c java_nio_channels_Pipe__24SinkChannel
// @dep_class b95b712f8b955018 java_nio_channels_SelectableChannel
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel
// @dep_class 9d3bd8ebcf76e5ce java_nio_channels_spi_AbstractSelectableChannel

// header file dependencies
// @dep_header java_nio_channels_Pipe__24SinkChannel

#include "java/nio/channels/Pipe__24SinkChannel.h"

#ifndef _JC_gnu_java_nio_PipeImpl__24SinkChannelImpl_H_
#define _JC_gnu_java_nio_PipeImpl__24SinkChannelImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_refs	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_refs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_nonrefs	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$refs	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$refs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$nonrefs	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$nonrefs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object;

typedef const struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vmethods	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vmethods;
typedef const struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtable	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtable;
typedef const struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtype	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$_init$a269c60b1b74311c(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *, jint);

// Virtual methods
extern jint _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$getNativeFD$4ed008ed25fb0a89(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *);
extern void _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$implCloseSelectableChannel$315f020e75eca883(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *);
extern void _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$implConfigureBlocking$a0eca1c8bc794f2a(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, jboolean);
extern jint _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$write$5ecbda8c634879d7(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_java_nio_ByteBuffer$object *);
extern jlong _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$write$4ff5a795e8f49f07(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_object_array *);
extern jlong _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$write$1a4ff655d427cb5e(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_object_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method_info$getNativeFD$4ed008ed25fb0a89;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method_info$implCloseSelectableChannel$315f020e75eca883;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method_info$implConfigureBlocking$a0eca1c8bc794f2a;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method_info$write$5ecbda8c634879d7;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method_info$write$4ff5a795e8f49f07;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method_info$write$1a4ff655d427cb5e;

// Virtual methods structure
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vmethods {
	jint	(*getNativeFD$4ed008ed25fb0a89)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *);
	void	(*implCloseSelectableChannel$315f020e75eca883)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *);
	void	(*implConfigureBlocking$a0eca1c8bc794f2a)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, jboolean);
	jint	(*write$5ecbda8c634879d7)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_java_nio_ByteBuffer$object *);
	jlong	(*write$4ff5a795e8f49f07)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_object_array *);
	jlong	(*write$1a4ff655d427cb5e)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_object_array *, jint, jint);
};

// Vtable
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
	_jc_java_nio_channels_SelectableChannel$vmethods	java_nio_channels_SelectableChannel;
	_jc_java_nio_channels_spi_AbstractSelectableChannel$vmethods	java_nio_channels_spi_AbstractSelectableChannel;
	_jc_java_nio_channels_Pipe__24SinkChannel$vmethods	java_nio_channels_Pipe__24SinkChannel;
	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vmethods	gnu_java_nio_PipeImpl__24SinkChannelImpl;
};

// Vtype
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$refs {
    _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_refs	gnu_java_nio_PipeImpl__24SinkChannelImpl;
    _jc_java_nio_channels_Pipe__24SinkChannel$sub_refs	java_nio_channels_Pipe__24SinkChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_refs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_SelectableChannel$sub_refs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_nonrefs {
	jint	native__5ffd;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_nio_channels_SelectableChannel$sub_nonrefs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_nonrefs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_Pipe__24SinkChannel$sub_nonrefs	java_nio_channels_Pipe__24SinkChannel;
    _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_nonrefs	gnu_java_nio_PipeImpl__24SinkChannelImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object {
	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtype	*vtype;
	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtype _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_PipeImpl__24SinkChannelImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$class_object;

#endif	/* _JC_gnu_java_nio_PipeImpl__24SinkChannelImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/PipeImpl__24SinkChannelImpl.h <==
// public final class gnu.java.nio.PipeImpl$SinkChannelImpl

// class file dependencies
// @dep_class 605b501836d0d19a gnu_java_nio_PipeImpl__24SinkChannelImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8a9bac808797868c java_nio_channels_Pipe__24SinkChannel
// @dep_class b95b712f8b955018 java_nio_channels_SelectableChannel
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel
// @dep_class 9d3bd8ebcf76e5ce java_nio_channels_spi_AbstractSelectableChannel

// header file dependencies
// @dep_header java_nio_channels_Pipe__24SinkChannel

#include "java/nio/channels/Pipe__24SinkChannel.h"

#ifndef _JC_gnu_java_nio_PipeImpl__24SinkChannelImpl_H_
#define _JC_gnu_java_nio_PipeImpl__24SinkChannelImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_refs	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_refs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_nonrefs	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$refs	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$refs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$nonrefs	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$nonrefs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object;

typedef const struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vmethods	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vmethods;
typedef const struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtable	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtable;
typedef const struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtype	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$_init$a269c60b1b74311c(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$getNativeFD$4ed008ed25fb0a89(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$implCloseSelectableChannel$315f020e75eca883(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$implConfigureBlocking$a0eca1c8bc794f2a(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, jboolean) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$write$5ecbda8c634879d7(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_java_nio_ByteBuffer$object *) _JC_JCNI_ATTR;
extern jlong _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$write$4ff5a795e8f49f07(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern jlong _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method$write$1a4ff655d427cb5e(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_object_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method_info$getNativeFD$4ed008ed25fb0a89;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method_info$implCloseSelectableChannel$315f020e75eca883;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method_info$implConfigureBlocking$a0eca1c8bc794f2a;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method_info$write$5ecbda8c634879d7;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method_info$write$4ff5a795e8f49f07;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$method_info$write$1a4ff655d427cb5e;

// Virtual methods structure
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vmethods {
	jint	(*getNativeFD$4ed008ed25fb0a89)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *) _JC_JCNI_ATTR;
	void	(*implCloseSelectableChannel$315f020e75eca883)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *) _JC_JCNI_ATTR;
	void	(*implConfigureBlocking$a0eca1c8bc794f2a)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, jboolean) _JC_JCNI_ATTR;
	jint	(*write$5ecbda8c634879d7)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_java_nio_ByteBuffer$object *) _JC_JCNI_ATTR;
	jlong	(*write$4ff5a795e8f49f07)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	jlong	(*write$1a4ff655d427cb5e)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object *, struct _jc_object_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
	_jc_java_nio_channels_SelectableChannel$vmethods	java_nio_channels_SelectableChannel;
	_jc_java_nio_channels_spi_AbstractSelectableChannel$vmethods	java_nio_channels_spi_AbstractSelectableChannel;
	_jc_java_nio_channels_Pipe__24SinkChannel$vmethods	java_nio_channels_Pipe__24SinkChannel;
	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vmethods	gnu_java_nio_PipeImpl__24SinkChannelImpl;
};

// Vtype
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$refs {
    _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_refs	gnu_java_nio_PipeImpl__24SinkChannelImpl;
    _jc_java_nio_channels_Pipe__24SinkChannel$sub_refs	java_nio_channels_Pipe__24SinkChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_refs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_SelectableChannel$sub_refs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_nonrefs {
	jint	native__5ffd;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_nio_channels_SelectableChannel$sub_nonrefs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_nonrefs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_Pipe__24SinkChannel$sub_nonrefs	java_nio_channels_Pipe__24SinkChannel;
    _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$sub_nonrefs	gnu_java_nio_PipeImpl__24SinkChannelImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object {
	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtype	*vtype;
	_jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$vtype _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_PipeImpl__24SinkChannelImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$class_object;

#endif	/* _JC_gnu_java_nio_PipeImpl__24SinkChannelImpl_H_ */
